@@ -6,7 +6,7 @@ package Template::Tiny::Strict;
 
 use strict;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # Evaluatable expression
 my $EXPR = qr/ [a-z_][\w.]* /xs;
@@ -71,15 +71,18 @@ my $CONDITION = qr/
 
 sub new {
     my ( $class, %arg_for ) = @_;
-    bless {
+    return bless {
         TRIM          => $arg_for{TRIM},
         forbid_undef  => $arg_for{forbid_undef},
         forbid_unused => $arg_for{forbid_unused},
+        name          => ( $arg_for{name} // 'template' ),
         _undefined    => {},
         _used         => {},
     } => $class;
 }
 
+sub name { $_[0]->{name} }
+
 # Copy and modify
 sub preprocess {
     my $self = shift;
@@ -123,6 +126,9 @@ sub process {
     }
     if ($errors) {
         require Carp;
+        my $name = $self->name;
+        my $class = ref $self;
+        $errors = "$class processing for '$name' failed:\n$errors";
         Carp::croak($errors);
     }
 
@@ -259,7 +265,7 @@ Template::Tiny::Strict - Template Toolkit reimplemented in as little code as pos
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -267,6 +273,7 @@ version 1.16
         TRIM          => 1,
         forbid_undef  => $optional_boolean,
         forbid_unused => $optional_boolean,
+        name          => $optional_string,
     );
 
     # Print the template results to STDOUT
@@ -287,7 +294,7 @@ version 1.16
 =head1 DESCRIPTION
 
 B<Template::Tiny::Strict> is a drop-in replacement for L<Template::Tiny>. By default,
-the behavior is identical. However, we have two new I<optional> arguments you can pass
+the behavior is identical. However, we have new I<optional> arguments you can pass
 to the constructor:
 
 =over 4
@@ -306,9 +313,15 @@ C<croak> with an error such as:
 
     The following variables were passed to the template but unused: 'name'
 
+=item * C<name>
+
+Accepts a string as the "name" of the template. Errors will be reported with
+this name. Make it easier to track down the errant template if you are
+generating plenty of them.
+
 =back
 
-As a convenience, all errors are gathered and reported at once.
+All errors are gathered and reported at once.
 
 B<Note>: what follows is the remainder of the original POD.
 
@@ -329,7 +342,7 @@ the Perl regular expression engine.
 Only the default C<[% %]> tag style is supported.
 
 Both the C<[%+ +%]> style explicit whitespace and the C<[%- -%]> style
-explicit chomp B<are> support, although the C<[%+ +%]> version is unneeded
+explicit chomp B<are> supported, although the C<[%+ +%]> version is unneeded
 in practice as B<Template::Tiny::Strict> does not support default-enabled C<PRE_CHOMP>
 or C<POST_CHOMP>.
 
